// ECMAScript 5 strict mode
"use strict";

assert2(cr, "cr namespace not created");
assert2(cr.plugins_, "cr.plugins_ not created");

/////////////////////////////////////
// Plugin class
// *** CHANGE THE PLUGIN ID HERE *** - must match the "id" property in edittime.js
//          vvvvvvvv
cr.plugins_.VinoosIAP = function(runtime) {
    this.runtime = runtime;
};

(function() {

    /////////////////////////////////////
    // *** CHANGE THE PLUGIN ID HERE *** - must match the "id" property in edittime.js
    //                            vvvvvvvv
    var pluginProto = cr.plugins_.VinoosIAP.prototype;

    /////////////////////////////////////
    // Object type class
    pluginProto.Type = function(plugin) {
        this.plugin = plugin;
        this.runtime = plugin.runtime;
    };

    var typeProto = pluginProto.Type.prototype;

    // called on startup for each object type
    typeProto.onCreate = function() {};

    /////////////////////////////////////
    // Instance class
    pluginProto.Instance = function(type) {
        this.type = type;
        this.runtime = type.runtime;
    };

    var instanceProto = pluginProto.Instance.prototype;

    // called whenever an instance is created
    instanceProto.onCreate = function() {
        var self = this;
        if (typeof window['iap'] == 'undefined') {
            return;
        }
		
		var self = this;
		this.product_info = {};
		this.purchase_info = {};
		this.productId = "";
    };

    //////////////////////////////////////
    // Conditions
    function Cnds() {};

	Cnds.prototype.OnInitializeSuccess = function (){
		return true;
	};

	Cnds.prototype.OnInitializeFailed = function (){
		return true;
	};

	Cnds.prototype.OnGetDetailsSuccess = function (){
		return true;
	};

	Cnds.prototype.OnGetDetailsFailed = function (){
		return true;
	};
	
	Cnds.prototype.OnPurchaseSuccess = function (product_) {
		return product_ === this.productId;
	};
	
	Cnds.prototype.OnPurchaseFailed = function (product_) {
		return product_ === this.productId;
	};
	
    pluginProto.cnds = new Cnds();

    //////////////////////////////////////
    // Actions
    function Acts() {};

    Acts.prototype.Initialize = function() {
        var self = this;
        if (typeof window['iap'] == 'undefined') {
            return;
        } else {
            window.iap.Initialize(this.properties[0], this.properties[1], function(result) {
                self.runtime.trigger(cr.plugins_.VinoosIAP.prototype.cnds.OnInitializeSuccess, self);
            }, function(error) {
                self.runtime.trigger(cr.plugins_.VinoosIAP.prototype.cnds.OnInitializeFailed, self);
            });
        }
    };

    Acts.prototype.RequestPayment = function(sku, type) {
        var self = this;
        if (typeof window['iap'] == 'undefined') {
            return;
        } else {
			self.productId = sku;
            window.iap.RequestPayment(
				sku,
				type != 0 ? true : false,
				function(result) {
					self.purchase_info[result["productId"]] = { token: result["purchaseToken"], time: result["purchaseTime"], order: result["orderId"] };
					self.runtime.trigger(cr.plugins_.VinoosIAP.prototype.cnds.OnPurchaseSuccess, self);
				}, function(error) {
					self.runtime.trigger(cr.plugins_.VinoosIAP.prototype.cnds.OnPurchaseFailed, self);
				}
			);
        }
    };

    Acts.prototype.GetSkuDetails = function(skus) {
        var self = this;
        if (typeof window['iap'] == 'undefined') {
            return;
        } else {
            window.iap.GetSkuDetails(
				skus,
				function(result) {
					for (i in result) {
						var p = result[i];
						self.product_info[p["productId"]] = { title: p["title"], price: p["price"], description: p["description"] };	
					}
					self.runtime.trigger(cr.plugins_.VinoosIAP.prototype.cnds.OnGetDetailsSuccess, self);
				}, function(error) {
					self.runtime.trigger(cr.plugins_.VinoosIAP.prototype.cnds.OnGetDetailsFailed, self);
				}
			);
        }
    };

    pluginProto.acts = new Acts();

    //////////////////////////////////////
    // Expressions
    function Exps() {};

	Exps.prototype.PurchaseToken = function (ret, sku) {
		ret.set_string(this.purchase_info[sku].token.toString());
	};
	
	Exps.prototype.PurchaseTime = function (ret, sku) {
		ret.set_string(this.purchase_info[sku].time.toString());
	};
	
	Exps.prototype.PurchaseOrderId = function (ret, sku) {
		ret.set_string(this.purchase_info[sku].order.toString());
	};
	
	Exps.prototype.ProductTitle = function (ret, sku) {
		ret.set_string(this.product_info[sku].title.toString());
	};
	
	Exps.prototype.ProductPrice = function (ret, sku) {
		ret.set_string(this.product_info[sku].price.toString());
	};
	
	Exps.prototype.ProductDescription = function (ret, sku) {
		ret.set_string(this.product_info[sku].description.toString());
	};

    pluginProto.exps = new Exps();

}());